==> zio-aws-datasync_2.12-7.21.15.11-sources.jar: zio/aws/datasync/model/CreateLocationEfsRequest.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.{
  IamRoleArn,
  EfsAccessPointArn,
  EfsFilesystemArn,
  EfsSubdirectory
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateLocationEfsRequest(
    subdirectory: Optional[EfsSubdirectory] = Optional.Absent,
    efsFilesystemArn: EfsFilesystemArn,
    ec2Config: zio.aws.datasync.model.Ec2Config,
    tags: Optional[Iterable[zio.aws.datasync.model.TagListEntry]] =
      Optional.Absent,
    accessPointArn: Optional[EfsAccessPointArn] = Optional.Absent,
    fileSystemAccessRoleArn: Optional[IamRoleArn] = Optional.Absent,
    inTransitEncryption: Optional[
      zio.aws.datasync.model.EfsInTransitEncryption
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest = {
    import CreateLocationEfsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
      .builder()
      .optionallyWith(
        subdirectory.map(value =>
          EfsSubdirectory.unwrap(value): java.lang.String
        )
      )(_.subdirectory)
      .efsFilesystemArn(
        EfsFilesystemArn.unwrap(efsFilesystemArn): java.lang.String
      )
      .ec2Config(ec2Config.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        accessPointArn.map(value =>
          EfsAccessPointArn.unwrap(value): java.lang.String
        )
      )(_.accessPointArn)
      .optionallyWith(
        fileSystemAccessRoleArn.map(value =>
          IamRoleArn.unwrap(value): java.lang.String
        )
      )(_.fileSystemAccessRoleArn)
      .optionallyWith(inTransitEncryption.map(value => value.unwrap))(
        _.inTransitEncryption
      )
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly =
    zio.aws.datasync.model.CreateLocationEfsRequest.wrap(buildAwsValue())
}
object CreateLocationEfsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationEfsRequest =
      zio.aws.datasync.model.CreateLocationEfsRequest(
        subdirectory.map(value => value),
        efsFilesystemArn,
        ec2Config.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        accessPointArn.map(value => value),
        fileSystemAccessRoleArn.map(value => value),
        inTransitEncryption.map(value => value)
      )
    def subdirectory: Optional[EfsSubdirectory]
    def efsFilesystemArn: EfsFilesystemArn
    def ec2Config: zio.aws.datasync.model.Ec2Config.ReadOnly
    def tags: Optional[List[zio.aws.datasync.model.TagListEntry.ReadOnly]]
    def accessPointArn: Optional[EfsAccessPointArn]
    def fileSystemAccessRoleArn: Optional[IamRoleArn]
    def inTransitEncryption
        : Optional[zio.aws.datasync.model.EfsInTransitEncryption]
    def getSubdirectory: ZIO[Any, AwsError, EfsSubdirectory] =
      AwsError.unwrapOptionField("subdirectory", subdirectory)
    def getEfsFilesystemArn: ZIO[Any, Nothing, EfsFilesystemArn] =
      ZIO.succeed(efsFilesystemArn)
    def getEc2Config
        : ZIO[Any, Nothing, zio.aws.datasync.model.Ec2Config.ReadOnly] =
      ZIO.succeed(ec2Config)
    def getTags: ZIO[Any, AwsError, List[
      zio.aws.datasync.model.TagListEntry.ReadOnly
    ]] = AwsError.unwrapOptionField("tags", tags)
    def getAccessPointArn: ZIO[Any, AwsError, EfsAccessPointArn] =
      AwsError.unwrapOptionField("accessPointArn", accessPointArn)
    def getFileSystemAccessRoleArn: ZIO[Any, AwsError, IamRoleArn] = AwsError
      .unwrapOptionField("fileSystemAccessRoleArn", fileSystemAccessRoleArn)
    def getInTransitEncryption
        : ZIO[Any, AwsError, zio.aws.datasync.model.EfsInTransitEncryption] =
      AwsError.unwrapOptionField("inTransitEncryption", inTransitEncryption)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ) extends zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly {
    override val subdirectory: Optional[EfsSubdirectory] = zio.aws.core.internal
      .optionalFromNullable(impl.subdirectory())
      .map(value => zio.aws.datasync.model.primitives.EfsSubdirectory(value))
    override val efsFilesystemArn: EfsFilesystemArn =
      zio.aws.datasync.model.primitives
        .EfsFilesystemArn(impl.efsFilesystemArn())
    override val ec2Config: zio.aws.datasync.model.Ec2Config.ReadOnly =
      zio.aws.datasync.model.Ec2Config.wrap(impl.ec2Config())
    override val tags
        : Optional[List[zio.aws.datasync.model.TagListEntry.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.datasync.model.TagListEntry.wrap(item)
          }.toList
        )
    override val accessPointArn: Optional[EfsAccessPointArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accessPointArn())
        .map(value =>
          zio.aws.datasync.model.primitives.EfsAccessPointArn(value)
        )
    override val fileSystemAccessRoleArn: Optional[IamRoleArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.fileSystemAccessRoleArn())
        .map(value => zio.aws.datasync.model.primitives.IamRoleArn(value))
    override val inTransitEncryption
        : Optional[zio.aws.datasync.model.EfsInTransitEncryption] =
      zio.aws.core.internal
        .optionalFromNullable(impl.inTransitEncryption())
        .map(value => zio.aws.datasync.model.EfsInTransitEncryption.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ): zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-datasync_3-5.17.126.1-sources.jar: zio/aws/datasync/model/CreateLocationEfsRequest.scala <==
package zio.aws.datasync.model
import zio.aws.datasync.model.primitives.{EfsFilesystemArn, EfsSubdirectory}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateLocationEfsRequest(
    subdirectory: Option[EfsSubdirectory] = None,
    efsFilesystemArn: EfsFilesystemArn,
    ec2Config: zio.aws.datasync.model.Ec2Config,
    tags: Option[Iterable[zio.aws.datasync.model.TagListEntry]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest = {
    import CreateLocationEfsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
      .builder()
      .optionallyWith(
        subdirectory.map(value =>
          EfsSubdirectory.unwrap(value): java.lang.String
        )
      )(_.subdirectory)
      .efsFilesystemArn(
        EfsFilesystemArn.unwrap(efsFilesystemArn): java.lang.String
      )
      .ec2Config(ec2Config.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly =
    zio.aws.datasync.model.CreateLocationEfsRequest.wrap(buildAwsValue())
}
object CreateLocationEfsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.datasync.model.CreateLocationEfsRequest =
      zio.aws.datasync.model.CreateLocationEfsRequest(
        subdirectory.map(value => value),
        efsFilesystemArn,
        ec2Config.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def subdirectory: Option[EfsSubdirectory]
    def efsFilesystemArn: EfsFilesystemArn
    def ec2Config: zio.aws.datasync.model.Ec2Config.ReadOnly
    def tags: Option[List[zio.aws.datasync.model.TagListEntry.ReadOnly]]
    def getSubdirectory: ZIO[Any, AwsError, EfsSubdirectory] =
      AwsError.unwrapOptionField("subdirectory", subdirectory)
    def getEfsFilesystemArn: ZIO[Any, Nothing, EfsFilesystemArn] =
      ZIO.succeed(efsFilesystemArn)
    def getEc2Config
        : ZIO[Any, Nothing, zio.aws.datasync.model.Ec2Config.ReadOnly] =
      ZIO.succeed(ec2Config)
    def getTags: ZIO[Any, AwsError, List[
      zio.aws.datasync.model.TagListEntry.ReadOnly
    ]] = AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ) extends zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly {
    override val subdirectory: Option[EfsSubdirectory] = scala
      .Option(impl.subdirectory())
      .map(value => zio.aws.datasync.model.primitives.EfsSubdirectory(value))
    override val efsFilesystemArn: EfsFilesystemArn =
      zio.aws.datasync.model.primitives
        .EfsFilesystemArn(impl.efsFilesystemArn())
    override val ec2Config: zio.aws.datasync.model.Ec2Config.ReadOnly =
      zio.aws.datasync.model.Ec2Config.wrap(impl.ec2Config())
    override val tags
        : Option[List[zio.aws.datasync.model.TagListEntry.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.datasync.model.TagListEntry.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.datasync.model.CreateLocationEfsRequest
  ): zio.aws.datasync.model.CreateLocationEfsRequest.ReadOnly = new Wrapper(
    impl
  )
}
